pub enum ComplexTypeKind {
Value,
Entity,
Function,
}Expand description
A bit of terminology:
- Complex types include
enum,struct,class, tuple, and function types. - Recursive but not complex types are pointers, optionals, and arrays.
- Placeholders are temporaries that stand in for named types.
- The rest of the types are called atomic or simple. They include numeric types (bool, integral, floating-point), Strings, Dates and Blobs.
- User-defined types are
enums,structs andclasses. - Named types are also enums, structs and classes, along with the built-in types (e.g. numeric types, strings, etc.).
- Product types are
structs,classes and tuples. - Value types are enums, structs, and tuples, along with the built-in types.
- Entity types are only classes (for now).
- Function types are… function types, obviously.
Variants
Value
A complex type that is a value type: struct, enum, tuple
Entity
A complex type that is an entity type: currently, only class.
Function
A complex type that is a function type.