pub enum NameTransform {
Identity,
LowerSnakeCase,
UpperSnakeCase,
LowerCamelCase,
UpperCamelCase,
}Expand description
The rewriting strategy applied to various kinds of named program elements,
such as function, variable, and type names.
In the CodegenParams struct, optional instances of this transform are
specified, where None means “default for the programming language”.
Variants
Identity
Don’t touch it!
LowerSnakeCase
lower_snake_case. Isn’t SnakeCase spelled with camel case ironic, by the way?
UpperSnakeCase
UPPER_SNAKE_CASE. Use this only when you are frustrated and want to yell.
LowerCamelCase
lowerCamelCase.
UpperCamelCase
UpperCamelCase, also known as PascalCase.