pub struct CodegenParams {
pub database: DatabaseEngine,
pub language: Language,
pub database_access_mode: Option<DatabaseAccessMode>,
pub namespace: Option<String>,
pub type_name_transform: Option<NameTransform>,
pub field_name_transform: Option<NameTransform>,
pub variant_name_transform: Option<NameTransform>,
pub func_name_transform: Option<NameTransform>,
pub namespace_transform: Option<NameTransform>,
}Expand description
A bunch of centralized settings governing the behavior of DALGen.
Fields
database: DatabaseEngineThe database flavor to be targeted. See the docs of DatabaseEngine.
language: LanguageThe programming language to be targeted. See the docs of Language.
database_access_mode: Option<DatabaseAccessMode>Database access strategy. See the docs for DatabaseAccessMode.
namespace: Option<String>Namespace name. This will be used in different ways for different programming languages. For example, in Go, it will be the package name, and is thus mandatory.
type_name_transform: Option<NameTransform>The transform to be applied to names of user-defined types.
field_name_transform: Option<NameTransform>The transform to be applied to fields of structs and classes.
variant_name_transform: Option<NameTransform>The transform to be applied to variants of enums.
func_name_transform: Option<NameTransform>The transform to be applied to names of user-defined functions.
namespace_transform: Option<NameTransform>The transform to be applied to the name of the namespace.